intelmq.bots.outputs.files package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.outputs.files package

## Submodules

## intelmq.bots.outputs.files.output module

intelmq.bots.outputs.files.output.BOT

  alias of `intelmq.bots.outputs.files.output.FilesOutputBot`

class intelmq.bots.outputs.files.output.FilesOutputBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  Write events lockfree into separate files

  _get_new_name(fd=None)

    Creates unique filename (Maildir inspired)

  create_unique_file()

    Safely creates machine-wide uniquely named file in tmp dir.

  dir: str = '/opt/intelmq/var/lib/bots/files-output/incoming'
  hierarchical_output: bool = False
  init()
  keep_raw_field: bool = False
  message_jsondict_as_string: bool = False
  message_with_type: bool = False
  process()
  single_key: bool = False
  suffix: str = '.json'
  tmp: str = '/opt/intelmq/var/lib/bots/files-output/tmp'

## Module contents